Howdoi SimpleBot plugin
=======================

.. image:: https://img.shields.io/github/v/release/simplebot-org/simplebot_howdoi
   :target: https://pypi.org/project/simplebot_howdoi

.. image:: https://img.shields.io/pypi/pyversions/simplebot_howdoi.svg
   :target: https://pypi.org/project/simplebot_howdoi

.. image:: https://pepy.tech/badge/simplebot_howdoi
   :target: https://pepy.tech/project/simplebot_howdoi

.. image:: https://img.shields.io/github/license/simplebot-org/simplebot_howdoi
   :target: https://github.com/simplebot-org/simplebot_howdoi/blob/master/LICENSE

.. image:: https://img.shields.io/badge/code%20style-black-000000.svg
   :target: https://github.com/psf/black

`SimpleBot`_ plugin that allows to get instant programming answers in Delta Chat, powered by `howdoi <https://github.com/gleitz/howdoi>`_

Install
-------

To install run::

  pip install simplebot-howdoi


.. _SimpleBot: https://github.com/simplebot-org/simplebot
